"""Bbq group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

BBQ_TASKS = {
    "bbq": f"{BASE_IMPORT}bbq:BbqExtractor",
}
